@@ -1,5 +1,6 @@
 import os
 import sys
+import platform
 
 import argparse
 import colorama
@@ -16,8 +17,10 @@ except ModuleNotFoundError:
 
 
 
-full_path = os.path.realpath(__file__).split("/")
-BASE = f"{'/'.join(full_path[:-1])}"
+SEP = '\\' if platform.system() == "Windows" else '/'
+full_path = os.path.realpath(__file__).split(SEP)
+BASE = f"{SEP.join(full_path[:-1])}"
+
 
 
 def check_positive(value):
@@ -45,7 +48,7 @@ def parse_args(args):
     parser.add_argument(
         "-t",
         "--titles",
-        help="a plain text file containing the desired titles and artists of the songs in the playlist, each on a new line. Format: title<@>artist",
+        help="a plain text file containing the desired titles and artists of the songs in the playlist, each on a new line. Format: title<@>artist. Note: if the --album flag is not set, each entry in this file is treated as a single with its own title, artist, album and cover art. In this case, title, artist and album are mandatory and cover art is optional. Format: title<@>artist<@>album[<@>local path or url to image]",
     )
     parser.add_argument(
         "-d",
@@ -112,23 +115,23 @@ def main():
     if "--check" in sys.argv[1:] or "-k" in sys.argv[1:]:
         print("Initialising.")
         urls = Playlist("https://www.youtube.com/playlist?list=PLOoPqX_q5JAVPMhHjYxcUc2bxTDMyGE-a")
-        playlist_title = urls.title()
+        playlist_title = urls.title
         start = 0
         end = len(urls)
         album = "Test Album"
-        directory = "music/"
+        directory = f"music{SEP}"
         artist = "Test Artist"
         is_album = True
         proxies = None
-        image = f"{BASE}/check/check.jpg"
-        titles = f"{BASE}/check/check.txt"
+        image = f"{BASE}{SEP}check{SEP}check.jpg"
+        titles = f"{BASE}{SEP}check{SEP}check.txt"
         mp3 = True
 
     else:
         args = parse_args(sys.argv[1:])
         print("Initialising.")
         urls = Playlist(args.url)
-        playlist_title = urls.title()
+        playlist_title = urls.title
         start = 0 if args.start is None else args.start - 1
         end = len(urls) if args.end is None else args.end
         album = playlist_title if args.album is None else args.album
